@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: execdir.cpp,v 1.7 2003/11/07 22:08:17 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: execdir.cpp,v 1.8 2007/01/06 18:46:56 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -130,10 +130,31 @@ getExecDir(void)
 }
 
 GURL 
-getDjVuDataFile(const char *fname)
+getDjViewDataFile(const char *fname)
 {
   GList<GURL> paths = DjVuMessage::GetProfilePaths();
   GUTF8String file = fname;
+
+  // end hack alert
+  static const char *osi = "/osi/";
+  static const char *djview3 = "/djview3/";
+  for (GPosition pos=paths; pos; ++pos)
+    {
+      GURL url = GURL(file, paths[pos]);
+      GUTF8String urls = (const char*)url;
+      int pos = urls.search(osi);
+      if (pos >= 0)
+        {
+          GUTF8String urlx;
+          urlx += urls.substr(0, pos);
+          urlx += djview3;
+          urlx += urls.substr(pos+strlen(osi), -1);
+          GURL url = GURL::UTF8(urlx);
+          if (url.is_file())
+            return url;
+        }
+    }
+  // end hack alert
   for (GPosition pos=paths; pos; ++pos)
     {
       GURL url = GURL(file, paths[pos]);
