@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: execdir.h,v 1.7 2003/11/07 22:08:17 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: execdir.h,v 1.8 2007/01/06 18:46:56 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef HDR_EXECDIR
 #define HDR_EXECDIR
@@ -68,6 +68,6 @@
 #include "GURL.h"
 
 GURL getExecDir(void);
-GURL getDjVuDataFile(const char *fname);
+GURL getDjViewDataFile(const char *fname);
 
 #endif
