@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: ByteStream.cpp,v 1.20 2005/12/24 12:45:01 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: ByteStream.cpp,v 1.22 2006/11/01 02:49:54 leonb Exp $
+// $Name: release_3_5_18 $
 
 // From: Leon Bottou, 1/31/2002
 // This file has very little to do with my initial implementation.
@@ -250,9 +250,6 @@ ByteStream::Memory::operator[] (int n)
 class ByteStream::Static : public ByteStream
 {
 public:
-  class Allocate;
-  class Duplicate;
-  friend class Duplicate;
 
   /** Creates a Static object for allocating the memory area of
       length #sz# starting at address #buffer#. */
@@ -266,9 +263,6 @@ public:
       Valid offsets for function #seek# range from 0 to the value returned
       by this function. */
   virtual int size(void) const;
-  virtual GP<ByteStream> duplicate(const size_t xsize) const;
-  /// Returns false, unless a subclass of ByteStream::Static
-  virtual bool is_static(void) const { return true; }
 protected:
   const char *data;
   int bsize;
@@ -278,53 +272,12 @@ private:
 
 ByteStream::Static::~Static() {}
 
-class ByteStream::Static::Allocate : public ByteStream::Static
-{
-public:
-  friend class ByteStream;
-protected:
-  char *buf;
-  GPBuffer<char> gbuf;
-public:
-  Allocate(const size_t size) : Static(0,size), gbuf(buf,size) { data=buf; }
-  virtual ~Allocate();
-};
-
-ByteStream::Static::Allocate::~Allocate() {}
-
 inline int
 ByteStream::Static::size(void) const
 {
   return bsize;
 }
 
-class ByteStream::Static::Duplicate : public ByteStream::Static
-{
-protected:
-  GP<ByteStream> gbs;
-public:
-  Duplicate(const ByteStream::Static &bs, const size_t size);
-};
-
-ByteStream::Static::Duplicate::Duplicate(
-  const ByteStream::Static &bs, const size_t xsize)
-: ByteStream::Static(0,0)
-{
-  if(xsize&&(bs.bsize<bs.where))
-  {
-    const size_t bssize=(size_t)bs.bsize-(size_t)bs.where;
-    bsize=(size_t)((xsize>bssize)?bssize:xsize);
-    gbs=const_cast<ByteStream::Static *>(&bs);
-    data=bs.data+bs.where;
-  }
-}
-
-GP<ByteStream>
-ByteStream::Static::duplicate(const size_t xsize) const
-{
-  return new ByteStream::Static::Duplicate(*this,xsize);
-}
-
 #if HAS_MEMMAP
 /** Read-only ByteStream interface to a memmap area.
     Class #MemoryMapByteStream# implements a read-only ByteStream interface
@@ -1201,31 +1154,6 @@ ByteStream::create_static(const void * buffer, size_t sz)
   return new Static(buffer, sz);
 }
 
-GP<ByteStream>
-ByteStream::duplicate(const size_t xsize) const
-{
-  GP<ByteStream> retval;
-  const long int pos=tell();
-  const int tsize=size();
-  ByteStream &self=*(const_cast<ByteStream *>(this));
-  if(tsize < 0 || pos < 0 || (unsigned int)tsize < 1+(unsigned int)pos)
-  {
-    retval=ByteStream::create();
-    retval->copy(self,xsize);
-    retval->seek(0L);
-  }else
-  {
-    const size_t s=(size_t)tsize-(size_t)pos;
-    const int size=(!xsize||(s<xsize))?s:xsize;
-    ByteStream::Static::Allocate *bs=new ByteStream::Static::Allocate(size);
-    retval=bs;
-    self.readall(bs->buf,size);
-  }
-  self.seek(pos,SEEK_SET,true);
-  return retval;
-}
-
-
 #if HAS_MEMMAP
 MemoryMapByteStream::MemoryMapByteStream(void)
 : ByteStream::Static(0,0)
@@ -1247,30 +1175,19 @@ GUTF8String
 MemoryMapByteStream::init(const int fd,const bool closeme)
 {
   GUTF8String retval;
+  data = (char*)(-1);
 #if defined(PROT_READ) && defined(MAP_SHARED)
   struct stat statbuf;
-  if(!fstat(fd,&statbuf))
-  {
-    if(statbuf.st_size)
+  if(!fstat(fd,&statbuf) && statbuf.st_size)
     {
       bsize=statbuf.st_size;
       data=(char *)mmap(0,statbuf.st_size,PROT_READ,MAP_SHARED,fd,0);
     }
-  }else
-  {
-    if(closeme)
-    {
-      close(fd);
-    }
-    retval= ERR_MSG("ByteStream.open_fail2");
-  }
-#else
-  retval= ERR_MSG("ByteStream.open_fail2");
 #endif
+  if(data == (char *)(-1))
+    retval = ERR_MSG("ByteStream.open_fail2");
   if(closeme)
-  {
     close(fd);
-  }
   return retval;
 }
 
