@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: ByteStream.h,v 1.13 2006/01/31 15:28:30 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: ByteStream.h,v 1.14 2006/11/01 02:49:54 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef _BYTESTREAM_H
 #define _BYTESTREAM_H
@@ -97,7 +97,7 @@
 
 
     @version
-    #$Id: ByteStream.h,v 1.13 2006/01/31 15:28:30 leonb Exp $# */
+    #$Id: ByteStream.h,v 1.14 2006/11/01 02:49:54 leonb Exp $# */
 //@{
 
 
@@ -226,10 +226,6 @@ public:
       until reaching the end-of-file mark on ByteStream #bsfrom#, regardless
       of the number of bytes transferred.  */
   size_t copy(ByteStream &bsfrom, size_t size=0);
-  /** Create a new #ByteStream# that copies the data from this #ByteStream#
-      starting from the current position, upto #size# bytes.  Setting the
-      #size# to zero means copy to the end-of-file mark. */
-  GP<ByteStream> duplicate(const size_t size=0) const;
   /// Allows printf() type operations to a bytestream.
   size_t format(const char *fmt, ... );
   /// Allows scanf() type operations on a bytestream.
@@ -281,8 +277,6 @@ public:
       bytes at position #pos# into #buffer# and returns the actual number of
       bytes read.  The current position is unchanged. */
   virtual size_t readat(void *buffer, size_t sz, int pos);
-  /// Returns false, unless a subclass of ByteStream::Static
-  virtual bool is_static(void) const { return false; }
   //@}
 protected:
   ByteStream(void) : cp(AUTO) {};
