@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DataPool.h,v 1.10 2003/11/07 22:08:20 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: DataPool.h,v 1.11 2006/11/19 13:53:35 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef _DATAPOOL_H
 #define _DATAPOOL_H
@@ -96,7 +96,7 @@ class ByteStream;
 
     @memo Thread safe data storage
     @author Andrei Erofeev <eaf@geocities.com>
-    @version #$Id: DataPool.h,v 1.10 2003/11/07 22:08:20 leonb Exp $#
+    @version #$Id: DataPool.h,v 1.11 2006/11/19 13:53:35 leonb Exp $#
 */
 
 //@{
@@ -508,7 +508,6 @@ public:
 	  @param callback Function to call
 	  @param cl_data Argument to pass to the callback when it's called. */
    void		add_trigger(int start, int length,
-//			    void (* callback)(GP<GPEnabled> &), GP<GPEnabled> cl_data);
 			    void (* callback)(void *), void * cl_data);
 
       /** Associates the specified {\em trigger callback} with the
@@ -518,14 +517,15 @@ public:
 	  The callback will be called when there is data available for
 	  every offset from #0# to #thresh#, if #thresh# is positive, or
 	  when #EOF# condition has been set otherwise. */
-//   void		add_trigger(int thresh, void (* callback)(GP<GPEnabled> &), GP<GPEnabled> cl_data);
-   void		add_trigger(int thresh, void (* callback)(void *), void * cl_data);
+
+   void		add_trigger(int thresh, 
+                            void (* callback)(void *), void * cl_data);
 
       /** Use this function to unregister callbacks, which are no longer
 	  needed. {\bf Note!} It's important to do it when the client
 	  is about to be destroyed. */
    void		del_trigger(void (* callback)(void *), void *  cl_data);
-//   void		del_trigger(void (* callback)(GP<GPEnabled> &), GP<GPEnabled>  cl_data);
+
       //@}
 
       /** Loads data from the file into memory. This function is only useful
@@ -554,6 +554,8 @@ public:
       /** Useful in comparing data pools.  Returns true if dirived from
           same URL or bytestream. */
    bool simple_compare(DataPool &pool) const;
+
+
 private:
    bool		eof_flag;
    bool		stop_flag;
