@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuDocEditor.cpp,v 1.13 2005/05/25 20:24:52 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: DjVuDocEditor.cpp,v 1.14 2006/11/01 02:49:54 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -457,7 +457,7 @@ DjVuDocEditor::insert_file(const GURL &file_url, const GUTF8String &parent_id,
      file_pool=source->request_data(source, file_url);
      if(source != this)
      {
-       file_pool=DataPool::create(file_pool->get_stream()->duplicate());
+       file_pool=DataPool::create(file_pool->get_stream());
      }
    }
    if(file_pool && file_url && DjVuDocument::djvu_import_codec)
