@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuFile.cpp,v 1.12 2005/12/24 12:45:01 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: DjVuFile.cpp,v 1.14 2006/10/05 15:51:03 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -1208,9 +1208,12 @@ DjVuFile::decode_chunk( const GUTF8String &id, const GP<ByteStream> &gbs,
       iffout.put_chunk(id);
       iffout.copy(achunk);
       iffout.close_chunk();
-//      desc.format( ERR_MSG("DjVuFile.text") );
     }
-
+  else if (chkid == "CELX")
+    {
+      G_THROW( ERR_MSG("DjVuFile.securedjvu") );
+    }
+  
   // Return description
   return desc;
 }
@@ -1506,9 +1509,12 @@ DjVuFile::decode_ndir(GMap<GURL, void *> & map)
     IFFByteStream &iff=*giff;
     if (!iff.get_chunk(chkid)) 
       REPORT_EOF(true)
-      
+
     int chunks=0;
     int last_chunk=0;
+#ifndef SLOW_BUT_EXACT_DETECTION_OF_NDIR
+    int found_incl=0;
+#endif
     G_TRY
     {
       int chunks_left=(recover_errors>SKIP_PAGES)?chunks_number:(-1);
@@ -1523,6 +1529,12 @@ DjVuFile::decode_ndir(GMap<GURL, void *> & map)
           dir=d;
           break;
         }
+#ifndef SLOW_BUT_EXACT_DETECTION_OF_NDIR
+        if (chkid=="INCL")
+          found_incl = 1;
+        if (chunks>2 && !found_incl && !data_pool->is_eof())
+          return 0;
+#endif
         iff.seek_close_chunk();
       }
       if ((!dir)&&(chunks_number < 0)) chunks_number=last_chunk;
