@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GBitmap.cpp,v 1.11 2005/12/24 12:45:01 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: GBitmap.cpp,v 1.12 2006/07/21 18:38:59 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -69,7 +69,7 @@
 #include "GException.h"
 #include <string.h>
 
-// File "$Id: GBitmap.cpp,v 1.11 2005/12/24 12:45:01 leonb Exp $"
+// File "$Id: GBitmap.cpp,v 1.12 2006/07/21 18:38:59 leonb Exp $"
 // - Author: Leon Bottou, 05/1997
 
 
@@ -298,6 +298,7 @@ GBitmap::init(ByteStream &ref, int aborder)
   char lookahead = '\n';
   int acolumns = read_integer(lookahead, ref);
   int arows = read_integer(lookahead, ref);
+  int maxval = 1;
   init(arows, acolumns, aborder);
   // go reading file
   if (magic[0]=='P')
@@ -309,20 +310,22 @@ GBitmap::init(ByteStream &ref, int aborder)
           read_pbm_text(ref); 
           return;
         case '2':
-          grays = 1 + read_integer(lookahead, ref);
-          if (grays > 256)
-            G_THROW("Cannot read PGM with depth greater than 8 bits.");
-          read_pgm_text(ref); 
+          maxval = read_integer(lookahead, ref);
+          if (maxval > 65535)
+            G_THROW("Cannot read PGM with depth greater than 16 bits.");
+          grays = (maxval>255 ? 256 : maxval+1);
+          read_pgm_text(ref, maxval); 
           return;
         case '4':
           grays = 2;
           read_pbm_raw(ref); 
           return;
         case '5':
-          grays = 1 + read_integer(lookahead, ref);
-          if (grays > 256)
-            grays = 256;
-          read_pgm_raw(ref); 
+          maxval = read_integer(lookahead, ref);
+          if (maxval > 65535)
+            G_THROW("Cannot read PGM with depth greater than 16 bits.");
+          grays = (maxval>255 ? 256 : maxval+1);
+          read_pgm_raw(ref, maxval); 
           return;
         }
     }
@@ -793,15 +796,18 @@ GBitmap::read_pbm_text(ByteStream &bs)
 }
 
 void 
-GBitmap::read_pgm_text(ByteStream &bs)
+GBitmap::read_pgm_text(ByteStream &bs, int maxval)
 {
   unsigned char *row = bytes_data + border;
   row += (nrows-1) * bytes_per_row;
   char lookahead = '\n';
+  GTArray<unsigned char> ramp(0, maxval);
+  for (int i=0; i<=maxval; i++)
+    ramp[i] = (i<maxval ? ((grays-1)*(maxval-i) + maxval/2) / maxval : 0);
   for (int n = nrows-1; n>=0; n--) 
     {
       for (int c = 0; c<ncolumns; c++)
-        row[c] = grays - 1 - read_integer(lookahead, bs);
+        row[c] = ramp[read_integer(lookahead, bs)];
       row -= bytes_per_row;
     }
 }
@@ -833,17 +839,34 @@ GBitmap::read_pbm_raw(ByteStream &bs)
 }
 
 void 
-GBitmap::read_pgm_raw(ByteStream &bs)
+GBitmap::read_pgm_raw(ByteStream &bs, int maxval)
 {
+  int maxbin = (maxval>255) ? 65536 : 256;
+  GTArray<unsigned char> ramp(0, maxbin-1);
+  for (int i=0; i<maxbin; i++)
+    ramp[i] = (i<maxval ? ((grays-1)*(maxval-i) + maxval/2) / maxval : 0);
+  unsigned char *bramp = ramp;
   unsigned char *row = bytes_data + border;
   row += (nrows-1) * bytes_per_row;
   for (int n = nrows-1; n>=0; n--) 
     {
-      for (int c = 0; c<ncolumns; c++)
+      if (maxbin > 256)
         {
-          unsigned char x;
-          bs.read((void*)&x, 1);
-          row[c] = grays - 1 - x;
+          for (int c = 0; c<ncolumns; c++)
+            {
+              unsigned char x[2];
+              bs.read((void*)&x, 2);
+              row[c] = bramp[x[0]*256+x[1]];
+            }
+        }
+      else
+        {
+          for (int c = 0; c<ncolumns; c++)
+            {
+              unsigned char x;
+              bs.read((void*)&x, 1);
+              row[c] = bramp[x];
+            }
         }
       row -= bytes_per_row;
     }
