@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GBitmap.h,v 1.9 2004/04/17 23:56:11 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: GBitmap.h,v 1.12 2007/01/08 23:59:38 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef _GBITMAP_H_
 #define _GBITMAP_H_
@@ -101,7 +101,7 @@ class ByteStream;
     @author
     L\'eon Bottou <leonb@research.att.com>
     @version
-    #$Id: GBitmap.h,v 1.9 2004/04/17 23:56:11 leonb Exp $#
+    #$Id: GBitmap.h,v 1.12 2007/01/08 23:59:38 leonb Exp $#
 
  */
 //@{
@@ -481,9 +481,9 @@ private:
   int encode(unsigned char *&pruns,GPBuffer<unsigned char> &gpruns) const;
   void decode(unsigned char *runs);
   void read_pbm_text(ByteStream &ref); 
-  void read_pgm_text(ByteStream &ref); 
+  void read_pgm_text(ByteStream &ref, int maxval); 
   void read_pbm_raw(ByteStream &ref); 
-  void read_pgm_raw(ByteStream &ref); 
+  void read_pgm_raw(ByteStream &ref, int maxval); 
   void read_rle_raw(ByteStream &ref); 
   static void append_long_run(unsigned char *&data, int count);
   static void append_line(unsigned char *&data,const unsigned char *row,
@@ -567,7 +567,8 @@ GBitmap::get_grays() const
 inline unsigned char *
 GBitmap::operator[](int row) 
 {
-  if (!bytes) uncompress();
+  if (!bytes) 
+    uncompress();
   if (row<0 || row>=nrows) {
 #ifndef NDEBUG
     if (zerosize < bytes_per_row + border)
@@ -581,7 +582,8 @@ GBitmap::operator[](int row)
 inline const unsigned char *
 GBitmap::operator[](int row) const
 {
-  if (!bytes) ((GBitmap*)this)->uncompress();
+  if (!bytes) 
+    ((GBitmap*)this)->uncompress();
   if (row<0 || row>=nrows) {
 #ifndef NDEBUG
     if (zerosize < bytes_per_row + border)
