@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GScaler.h,v 1.9 2003/11/07 22:08:21 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: GScaler.h,v 1.10 2006/11/13 22:53:14 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef _GSCALER_H_
 #define _GSCALER_H_
@@ -98,7 +98,7 @@ namespace DJVU {
     @author
     L\'eon Bottou <leonb@research.att.com>
     @version
-    #$Id: GScaler.h,v 1.9 2003/11/07 22:08:21 leonb Exp $# */
+    #$Id: GScaler.h,v 1.10 2006/11/13 22:53:14 leonb Exp $# */
 //@{
 
 
@@ -292,11 +292,11 @@ protected:
   GPixel *get_line(int, const GRect &, const GRect &, const GPixmap &);
   // Temporaries
   GPixel *lbuffer;
-  GPBufferBase glbuffer;
+  GPBuffer<GPixel> glbuffer;
   GPixel *p1;
-  GPBufferBase gp1;
+  GPBuffer<GPixel> gp1;
   GPixel *p2;
-  GPBufferBase gp2;
+  GPBuffer<GPixel> gp2;
   int    l1;
   int    l2;
 };
