@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GThreads.cpp,v 1.17 2006/02/21 17:27:34 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: GThreads.cpp,v 1.18 2006/10/05 15:51:03 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -381,7 +381,7 @@ GMonitor::wait(unsigned long timeout)
 
 
 // ----------------------------------------
-// MACTHREADS IMPLEMENTATION (from Praveen)
+// MACTHREADS IMPLEMENTATION (obsolete)
 // ----------------------------------------
 
 #if THREADMODEL==MACTHREADS
@@ -622,7 +622,8 @@ GMonitor::wait(unsigned long timeout)
 {
   // Timeouts are not used for anything important.
   // Just ignore the timeout and wait the regular way.
-  wait();
+  if (timeout > 0)
+    wait();
 }
 
 #endif
