@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: IFFByteStream.h,v 1.10 2003/11/07 22:08:21 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: IFFByteStream.h,v 1.11 2006/10/05 15:51:03 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef _IFFBYTESTREAM_H_
 #define _IFFBYTESTREAM_H_
@@ -121,7 +121,7 @@
 // with their re-implementation of ByteStreams.
 
     @version
-    #$Id: IFFByteStream.h,v 1.10 2003/11/07 22:08:21 leonb Exp $# */
+    #$Id: IFFByteStream.h,v 1.11 2006/10/05 15:51:03 leonb Exp $# */
 //@{
 
 
@@ -274,9 +274,12 @@ public:
       the stream is not valid for use after comparing, regardless of the
       result. */
   bool compare(IFFByteStream &iff);
-  /** #has_magic# is true if the stream has the DjVu file magic.
-   */
-  bool has_magic;
+  /** #has_magic_att# is true if the stream has 
+      the DjVu magic 'AT&T' marker. */
+  bool has_magic_att;
+  /** #has_magic_sdjv# is true if the stream has 
+      the Celartem magic 'SDJV' marker. */
+  bool has_magic_sdjv;
 private:
   // private datatype
   struct IFFContext
