@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: IW44Image.cpp,v 1.11 2004/08/06 15:11:29 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: IW44Image.cpp,v 1.12 2007/01/17 21:32:09 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -548,6 +548,7 @@ struct IW44Image::Alloc // DJVU_CLASS
 {
   Alloc *next;
   short data[IWALLOCSIZE];
+  Alloc(Alloc *n);
 };
 
 //---------------------------------------------------------------
@@ -619,19 +620,26 @@ IW44Image::Map::~Map()
   delete [] blocks;
 }
 
+
+IW44Image::Alloc::Alloc(Alloc *n)
+  : next(n) 
+{ 
+  // see note in IW44Image::Map::alloc
+  memset(data, 0, sizeof(data)); 
+}
+
 short *
 IW44Image::Map::alloc(int n)
 {
   if (top+n > IWALLOCSIZE)
     {
-      IW44Image::Alloc *n = new IW44Image::Alloc;
-      n->next = chain;
-      chain = n;
+      // note: everything is cleared long before we use it
+      // in order to avoid the need for a memory fence.
+      chain = new IW44Image::Alloc(chain);
       top = 0;
     }
   short *ans = chain->data + top;
   top += n;
-  memset((void*)ans, 0, sizeof(short)*n);
   return ans;
 }
 
