@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: JB2Image.cpp,v 1.10 2004/04/17 23:56:11 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: JB2Image.cpp,v 1.12 2007/01/08 23:59:38 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -470,7 +470,7 @@ JB2Dict::JB2Codec::CodeNum(int low, int high, NumContext *pctx, int v)
   bool negative=false;
   int cutoff;
   // Check
-  if (pctx && ((int)*pctx >= cur_ncell))
+  if (!pctx || ((int)*pctx >= cur_ncell))
     G_THROW( ERR_MSG("JB2Image.bad_numcontext") );
   // Start all phases
   cutoff = 0;
@@ -581,8 +581,7 @@ JB2Dict::JB2Codec::init_library(JB2Dict &jim)
     {
       shape2lib[i] = i;
       lib2shape[i] = i;
-      JB2Shape &jshp = jim.get_shape(i);
-      libinfo[i].compute_bounding_box(*(jshp.bits));
+      jim.get_bounding_box(i, libinfo[i]);
     }
 }
 
@@ -1060,19 +1059,24 @@ JB2Dict::JB2Codec::Decode::code(const GP<JB2Dict> &gjim)
     G_THROW( ERR_MSG("JB2Image.bad_number") );
   }
   JB2Dict &jim=*gjim;
-      // -------------------------
-      // THIS IS THE DECODING PART
-      // -------------------------
-      int rectype;
-      JB2Shape tmpshape;
-      do
-        {
-          code_record(rectype, gjim, &tmpshape);        
-        } 
-      while(rectype != END_OF_DATA);
-      if (!gotstartrecordp)
-        G_THROW( ERR_MSG("JB2Image.no_start") );
-      jim.compress();
+  // -------------------------
+  // THIS IS THE DECODING PART
+  // -------------------------
+  int rectype;
+  JB2Shape tmpshape;
+  do {
+    code_record(rectype, gjim, &tmpshape);        
+  } while(rectype != END_OF_DATA);
+  if (!gotstartrecordp)
+    G_THROW( ERR_MSG("JB2Image.no_start") );
+  // cache bounding boxes
+  int nshapes = jim.get_shape_count();
+  int ishapes = jim.get_inherited_shape_count();
+  jim.boxes.resize(0, nshapes-ishapes-1);
+  for (int i = ishapes; i < nshapes; i++)
+    jim.boxes[i-ishapes] = libinfo[i];
+  // compress
+  jim.compress();
 }
 
 
@@ -1362,9 +1366,9 @@ JB2Dict::JB2Codec::Decode::code(const GP<JB2Image> &gjim)
 ////////////////////////////////////////
 
 void 
-JB2Dict::JB2Codec::LibRect::compute_bounding_box(const GBitmap &bm)
+JB2Dict::LibRect::compute_bounding_box(const GBitmap &bm)
 {
-  // First lock the stuff.
+  // Avoid trouble
   GMonitorLock lock(bm.monitor());
   // Get size
   const int w = bm.columns();
@@ -1412,6 +1416,27 @@ JB2Dict::JB2Codec::LibRect::compute_bounding_box(const GBitmap &bm)
     }
 }
 
+
+void
+JB2Dict::get_bounding_box(int shapeno, LibRect &dest)
+{
+  if (shapeno < inherited_shapes && inherited_dict)
+    {
+      inherited_dict->get_bounding_box(shapeno, dest);
+    }
+  else if (shapeno >= inherited_shapes &&
+           shapeno < inherited_shapes + boxes.size())
+    {
+      dest = boxes[shapeno - inherited_shapes];
+    }
+  else
+    {
+      JB2Shape &jshp = get_shape(shapeno);
+      dest.compute_bounding_box(*(jshp.bits));
+    }
+}
+
+
 GP<JB2Dict>
 JB2Dict::create(void)
 {
