@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: JB2Image.h,v 1.9 2003/11/07 22:08:22 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: JB2Image.h,v 1.10 2007/01/08 23:59:38 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifndef _JB2IMAGE_H
 #define _JB2IMAGE_H
@@ -156,7 +156,7 @@
     \end{itemize}
 
     @version
-    #$Id: JB2Image.h,v 1.9 2003/11/07 22:08:22 leonb Exp $#
+    #$Id: JB2Image.h,v 1.10 2007/01/08 23:59:38 leonb Exp $#
     @memo
     Coding bilevel images with JB2.
     @author
@@ -321,11 +321,18 @@ public:
   /** Comment string coded by JB2 file. */
   GUTF8String comment;
 
+
 private:
   int inherited_shapes;
   GP<JB2Dict> inherited_dict;
   GArray<JB2Shape> shapes;
-  
+
+  struct LibRect {
+    int top,left,right,bottom;
+    void compute_bounding_box(const GBitmap &cbm);
+  };
+  GTArray<LibRect> boxes;
+  void get_bounding_box(int shapeno, LibRect &dest);
 };
 
 /** Main JB2 data structure.  Each #JB2Image# consists of an array of shapes
@@ -595,11 +602,6 @@ public:
   class Decode;
   class Encode;
   typedef unsigned int NumContext;
-  struct LibRect
-  {
-    int top,left,right,bottom;
-    void compute_bounding_box(const GBitmap &cbm);
-  };
   virtual ~JB2Codec();
 protected:
   // Constructors
