@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: MMX.cpp,v 1.10 2004/05/13 16:50:10 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: MMX.cpp,v 1.11 2007/01/08 22:03:35 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -133,6 +133,10 @@ int
 MMXControl::enable_mmx()
 {
   int cpuflags = 0;
+  const char *envvar = getenv("LIBDJVU_DISABLE_MMX");
+  if (envvar && envvar[0] && envvar[0]!='0')
+    return ((mmxflag = 0));
+  
 #if defined(MMX) && defined(__GNUC__) && defined(__i386__)
   // Detection of MMX for GCC
   __asm__ volatile ("pushl %%ebx\n\t"
