@@ -51,7 +51,7 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: ddjvu.cpp,v 1.25 2006/02/21 17:27:34 leonb Exp $
+// $Id: ddjvu.cpp,v 1.26 2006/10/05 15:51:03 leonb Exp $
 
 
 /* Program ddjvu has been rewritten to use the ddjvuapi only.
@@ -501,6 +501,9 @@ dopage(int pageno)
     die(i18n("Cannot access page %d."), pageno);
   while (! ddjvu_page_decoding_done(page))
     handle(TRUE);
+  if (ddjvu_page_decoding_error(page))
+    die(i18n("Cannot decode page %d."), pageno);
+  
   timingdata[1] = ticks();
   /* Open files */
   if (flag_format == 't') 
