@@ -51,8 +51,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: djvuserve.cpp,v 1.23 2006/02/21 17:27:34 leonb Exp $
-// $Name: release_3_5_17 $
+// $Id: djvuserve.cpp,v 1.26 2006/04/13 22:10:39 leonb Exp $
+// $Name: release_3_5_18 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -159,9 +159,11 @@ fprintdate(FILE *f, const char *fmt, const time_t *tim)
 }
 
 void
-headers(const struct stat *statbuf)
+headers(const struct stat *statbuf, const char *fname = 0)
 {
   fprintf(stdout,"Content-Type: image/x.djvu\n");
+  if (fname)
+    fprintf(stdout,"Content-Disposition: attachment; filename=\"%s\"\n", fname);
   fprintf(stdout,"Content-Length: %ld\n", (long)statbuf->st_size);
   time_t tim = time(0) + 360 * 24 * 3600;
   fprintdate(stdout, "Last-Modified: %s\n", &statbuf->st_mtime);
@@ -197,7 +199,7 @@ is_djvu_file_bundled(GURL &pathurl)
 }
 
 void 
-djvuserver_file(GURL pathurl)
+djvuserver_file(GURL pathurl, bool bundled, bool download)
 {
   GNativeString fname = pathurl.NativeFilename();
   struct stat statbuf;
@@ -205,7 +207,7 @@ djvuserver_file(GURL pathurl)
     G_THROW(strerror(errno));
   
   // Is this a bundled file?
-  if (is_djvu_file_bundled(pathurl))
+  if (is_djvu_file_bundled(pathurl) && !bundled)
     {
       // It is bundled
       GUTF8String id = pathurl.name();
@@ -216,7 +218,10 @@ djvuserver_file(GURL pathurl)
       return;
     }
   // Push the file
-  headers(&statbuf);
+  if (download)
+    headers(&statbuf, pathurl.fname());
+  else
+    headers(&statbuf);
   if (head) 
     return;
   fprintf(stdout,"\n");
@@ -321,6 +326,28 @@ djvuserver_component(GURL pathurl, GUTF8String id)
   out->copy(*bsin, frec->size);
 }
 
+
+bool
+search_cgi_arg(const char *name)
+{
+  const char *s = g().querystring;
+  int l = strlen(name);
+  if (*s == '?')
+    s += 1;
+  while (*s)
+    {
+      if (! strncmp(s, name, l))
+        if (s[l]=='&' || s[l]=='=' || s[l]==0)
+          return true;
+      while (*s && *s != '&')
+        s += 1;
+      if (*s == '&')
+        s += 1;
+    }
+  return false;
+}
+
+
 int
 main(int argc, char ** argv)
 {
@@ -330,6 +357,8 @@ main(int argc, char ** argv)
   G_TRY 
     {
       // Obtain path
+      bool bundled = false;
+      bool download = false;
       if (argc == 1)
         {
           cgi = true;
@@ -341,6 +370,10 @@ main(int argc, char ** argv)
             G_THROW("No path information");
           g().requestmethod = GNativeString(getenv("REQUEST_METHOD"));
           g().querystring = GUTF8String(getenv("QUERY_STRING"));
+          if (search_cgi_arg("bundled"))
+            bundled = true;
+          if (search_cgi_arg("download") || search_cgi_arg("bundle"))
+            bundled = download = true;
         }
       else if (argc == 2)
         {
@@ -359,7 +392,7 @@ main(int argc, char ** argv)
       GURL pathurl = GURL::Filename::UTF8(g().pathtranslated);
       if (pathurl.is_file())
         {
-          djvuserver_file(pathurl);
+          djvuserver_file(pathurl, bundled, download);
         }
       else
         {
@@ -367,10 +400,12 @@ main(int argc, char ** argv)
           pathurl = pathurl.base();
           if (! pathurl.is_file())
             G_THROW("File not found");
-          if (id == "index" || id == "index.djvu")
-            djvuserver_directory(pathurl);
-          else
+          if (id != "index" && id != "index.djvu")
             djvuserver_component(pathurl, id);
+          else if (bundled)
+            djvuserver_file(pathurl, bundled, download);
+          else
+            djvuserver_directory(pathurl);
         }
     }
   G_CATCH(ex)
